# Výběr vhodných úseků z OSM pomocí SQL dotazu

## Popis
Tento SQL dotaz slouží k výběru vhodných úseků komunikací a stezek z **OSM dat** v rámci **Definition Query** v aplikaci **ArcGIS Pro**. Pomocí dotazu se vybírají segmenty podle specifických kritérií, jako je typ komunikace, přístupnost a označení pro cyklisty.

---

## Kritéria výběru
1. **Typ komunikace**:
   - Zahrnuje kategorie jako `primary`, `residential`, `cycleway` a další.
2. **Vyloučení železnic**:
   - Železniční segmenty, jako `tram` nebo `rail`, jsou vynechány.
3. **Podmínky přístupu**:
   - Segmenty s omezeným přístupem (např. `no`, `private`) jsou vyloučeny.
4. **Cyklistická infrastruktura**:
   - Jsou zahrnuty pěší zóny a ulice, kde je cyklistika označená jako `designated` nebo povolená.

---

## Použití
Tento dotaz lze použít ve **Definition Query** vrstvy komunikací. Postup:
1. Otevřete vrstvu s daty OSM v **ArcGIS Pro**.
2. V panelu **Properties** zvolte záložku **Definition Query**.
3. Vložte níže uvedený SQL dotaz.
4. Výsledkem budou vyfiltrované úseky splňující daná kritéria.

---

## Aplikace v Rigorózní práci
- Kód byl použit pro výběr úseku výsledné datové sady založené na síti OSM. 

---

## Kód
```sql
(highway IN ('primary', 'residential', 'secondary', 'service', 'tertiary', 'track', 'cycleway', 'unclassified', 'path', 'secondary_link', 'tertiary_link', 'trunk') 
AND railway NOT IN ('tram', 'rail') 
AND access NOT IN ('no', 'permissive', 'private', 'restricted')) 

OR 

(highway IN ('pedestrian', 'footway', 'living_street') 
AND bicycle IN ('designated', 'yes') 
AND access NOT IN ('no', 'permissive', 'private', 'restricted')) 

OR 

(bicycle IN ('yes') 
AND access IN ('no'))
