# Identifikace cyklistických opatření v ArcGIS Arcade

## Popis
Tento výraz v jazyce **ArcGIS Arcade** slouží k identifikaci a kategorizaci cyklistických opatření na základě atributů liniových prvků v GIS vrstvě. Pomáhá automaticky třídit různé typy cyklistických tras a opatření, jako jsou **cyklopruhy, stezky pro cyklisty a chodce, cyklopiktogramy nebo cyklisté v protisměru**.

Výraz byl vytvořen jako součást rigorózní práce zaměřené na **analýzu a plánování cyklistické infrastruktury**.

---

## Jak to funguje
Výraz analyzuje hodnoty následujících atributů ve vrstvě:

- `highway`: Typ komunikace (např. `cycleway`, `footway`)
- `foot`: Povolení pro chodce (např. `yes`/`no`)
- `bicycle`: Povolení nebo označení pro cyklisty
- `cycleway`, `cycleway_right`, `cycleway_left`, `cycleway_both`: Specifikuje přítomnost cyklopruhů nebo jiných opatření
- `oneway`, `oneway_bicycle`: Informace o jednosměrném provozu a povolení cyklistům v protisměru

### Možné výstupy výrazu:
- **"Stezka pro cyklisty a chodce"**
- **"Stezka pro pěší s povoleným vjezdem cyklistů"**
- **"Cyklopruh"**
- **"Cyklopiktogram"**
- **"Cyklisté v protisměru"**
- **"Neznámý typ"**

---

## Požadavky

### Software
- **ArcGIS Pro** (verze 2.x nebo novější) nebo **ArcGIS Online**
- Vrstva s atributy odpovídajícími názvům v kódu (`highway`, `foot`, `bicycle`, `cycleway`, atd.)

### Data
Vrstva by měla obsahovat liniové prvky reprezentující komunikace nebo stezky s následujícími atributy:
- `highway` (např. `cycleway`, `footway`)
- `bicycle` (např. `yes`, `designated`)
- `cycleway` (např. `lane`, `shared_lane`)
- `oneway`, `oneway_bicycle` (např. `yes`, `no`)
- Další volitelné atributy: `cycleway_right`, `cycleway_left`, `cycleway_both`

*Pokud vaše data používají jiné názvy atributů, je třeba kód upravit tak, aby odpovídal vašim datům.*

---

## Použití
1. Otevřete projekt v **ArcGIS Pro** nebo **ArcGIS Online**.
2. Vyberte vrstvu obsahující data o komunikacích a jejich vlastnostech.
3. Vložte výraz do jednoho z následujících nástrojů:
   - **Field Calculator**: Pro vytvoření nového pole s kategoriemi cyklistických opatření.
   - **Pop-up Expression**: Pro zobrazení výsledků ve vyskakovacích oknech mapové aplikace.
4. Spusťte výraz a zkontrolujte výsledky.

---

## Kód
```javascript
var highway = $feature.highway;
var foot = $feature.foot;

var bicycle = $feature.bicycle;
var cycleway = $feature.cycleway;
var cycleway_right = $feature.cycleway_right;
var cycleway_left = $feature.cycleway_left;
var cycleway_both = $feature.cycleway_both;

var oneway = $feature.oneway;
var oneway_bicycle = $feature.oneway_bicycle;

if (highway == "cycleway" && (foot == "yes")) {
    return "Stezka pro cyklisty a chodce";
} else if (highway == "footway" && (bicycle == "designated" || bicycle == "yes")) {
    return "Stezka pro pěší s povoleným vjezdem cyklistů";
} else if (cycleway == "lane" || cycleway == "shared_lane" || cycleway == "share_busway" || cycleway_both == "lane" || cycleway_both == "shared_lane") {
    return "Cyklopruh";
} else if (cycleway == "opposite" || cycleway == "opposite_lane" || cycleway == "opposite_track" || oneway_bicycle == "no") {
    return "Cyklisté v protisměru";
} else if (cycleway == "pictogram" || cycleway_right == "pictogram" || cycleway_left == "pictogram" || cycleway_left == "shared_lane" || cycleway_right == "shared_lane") {
    return "Cyklopiktogram";
} else if (cycleway_right == "shared_lane" || cycleway_right == "lane" || cycleway_right == "share_busway" || cycleway_left == "share_busway" || cycleway_left == "shared_lane" || cycleway_left == "lane" || cycleway_left == "soft_lane" || cycleway_right == "soft_lane") {
    return "Cyklopruh";
} else {
    return "Neznámý typ";
}
