import requests
import json
from datetime import datetime
import os
import pandas as pd
import time

# URL pro Nextbike API - Brno + Kuřim
url = "https://api.nextbike.net/maps/nextbike-live.json?domains=te"

# Získání cesty ke skriptu
script_dir = os.path.dirname(os.path.abspath(__file__))  # Cesta ke složce se skriptem

# Název složky pro ukládání dat (vedle skriptu)
output_folder = os.path.join(script_dir, 'nextbike_data')

# Názvy souborů pro ukládání dat
filename_stanice = os.path.join(output_folder, "nextbike_stanice_data.csv")
filename_kola = os.path.join(output_folder, "nextbike_kola_data.csv")

# Vytvoření složky pro ukládání dat, pokud neexistuje
os.makedirs(output_folder, exist_ok=True)  # exist_ok=True zabrání chybě, pokud složka již existuje

while True:
    try:
        # Stáhnutí dat z API
        response = requests.get(url, timeout=10)

        # Kontrola, zda byl požadavek úspěšný
        if response.status_code == 200:
            # Parsování JSON dat
            data = json.loads(response.text)
            
            # Extrakce dat stanic
            stanice = data['countries'][0]['cities'][0]['places']
            
            # Vytvoření DataFrame z dat stanic
            df_stanice = pd.DataFrame(stanice)

            # Výběr požadovaných sloupců pro stanice
            df_stanice = df_stanice[['lat', 'lng', 'name', 'number', 'bikes']]
            
            # Přidání časové značky
            current_time = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
            df_stanice['timestamp'] = current_time
            
            # Vytvoření DataFrame pro kola
            kola_data = []
            for station in stanice:
                station_id = station['number']
                bike_numbers = station.get('bike_numbers', [])
                if isinstance(bike_numbers, list):
                    for bike_id in bike_numbers:
                        kola_data.append({
                            'station_id': station_id,
                            'bike_id': bike_id,
                            'timestamp': current_time
                        })
                else:
                    print(f"Varování: 'bike_numbers' není seznam pro stanici {station_id}")

            df_kola = pd.DataFrame(kola_data)
            
            # Uložení nebo aktualizace dat stanic v CSV souboru (přidávání řádků)
            if os.path.exists(filename_stanice):
                df_stanice.to_csv(filename_stanice, mode='a', header=False, index=False)
            else:
                df_stanice.to_csv(filename_stanice, index=False)
            
            # Uložení nebo aktualizace dat kol v CSV souboru (přidávání řádků)
            if os.path.exists(filename_kola):
                df_kola.to_csv(filename_kola, mode='a', header=False, index=False)
            else:
                df_kola.to_csv(filename_kola, index=False)
            
            print(f"Data stanic aktualizována v souboru: {filename_stanice}")
            print(f"Data kol aktualizována v souboru: {filename_kola}")
        else:
            print(f"Chyba při stahování dat: {response.status_code}")
    
    except Exception as e:
        print(f"Došlo k chybě: {e}")
    
    # Čekání 5 minut před dalším spuštěním
    time.sleep(300)
