# Detekce cyklistů pomocí YOLOv8

Tento projekt slouží k detekci cyklistů ve videích pomocí modelu **YOLOv8** a sledování jejich pohybu pomocí algoritmu **SORT**. Výsledky zahrnují počítání cyklistů pohybujících se zleva doprava a zprava doleva.

---

## **Požadavky**

- **Python**: Verze 3.8 nebo vyšší.
- **CUDA-kompatibilní GPU** (doporučeno pro rychlejší zpracování, ale není nutné).
- Knihovny uvedené v souboru `requirements.txt`.

---

## **Instalace**

1. **Klonujte oficiální YOLOv8 repozitář**:
   ```bash
   git clone https://github.com/ultralytics/ultralytics.git
   cd ultralytics
   pip install -r requirements.txt
   ```

2. **Nainstalujte balíček Ultralytics**:
   ```bash
   pip install ultralytics
   ```

3. **Stáhněte knihovnu SORT**:
   SORT je externí knihovna pro sledování objektů. Stáhněte ji z oficiálního GitHub repozitáře:
   ```bash
   git clone https://github.com/abewley/sort.git
   ```
   Poté přesuňte složku `sort` do hlavní složky projektu (`/cyklisti-detekce/`), aby ji mohl skript používat jako modul.

4. **Zkontrolujte instalaci PyTorch a dostupnost GPU** (volitelné):
   ```python
   import torch
   print("CUDA dostupná:", torch.cuda.is_available())
   if torch.cuda.is_available():
       print("GPU:", torch.cuda.get_device_name(0))
   ```

---

## **Použití**

1. Ujistěte se, že vstupní video je umístěno ve složce `/data/` (např. `data/cyklo_sestrih.mp4`).
2. Spusťte skript:
   ```bash
   python detect_cyclists.py
   ```
3. Výstupní video bude uloženo do složky `/outputs/` jako `output.mp4`.

---

## **Struktura projektu**
```
/cyklisti-detekce/
├── README.md          # Dokumentace projektu.
├── requirements.txt   # Seznam závislostí.
├── detect_cyclists.py # Hlavní Python skript.
├── /data/             # Složka s ukázkovými vstupy.
│   └── cyklo_sestrih.mp4 # Ukázkové video.
├── /outputs/          # Složka pro výstupy.
│   └── output.mp4     # Generované výstupní video.
└── /sort/             # Knihovna SORT pro sledování objektů.
```

---

## **Vysvětlení funkcionality**

- **YOLOv8**: Používá se k detekci cyklistů na jednotlivých snímcích videa.
- **SORT tracker**: Sleduje trajektorii cyklistů mezi snímky a počítá jejich pohyb přes definovanou čáru ve videu.
- **Výstup**: Video s anotacemi a počtem cyklistů pohybujících se v obou směrech.

---

## **Další poznámky**

- Pro podrobnější informace o YOLOv8 navštivte [dokumentaci Ultralytics](https://docs.ultralytics.com/quickstart/).
- Pro více informací o algoritmu SORT navštivte [GitHub repozitář SORT](https://github.com/abewley/sort).

---

