import requests
import xml.etree.ElementTree as ET
import pandas as pd
import os

# Cesta ke vstupnímu CSV souboru s kladem mapových listů
input_csv_path = r"./vstupni_data/klad_mapovych_listu.csv"

# Cesta k výstupní složce pro stažené ZIP soubory
output_folder = r"./vystup"

# Zajištění existence výstupní složky
os.makedirs(output_folder, exist_ok=True)

# Načtení CSV souboru
try:
    df = pd.read_csv(input_csv_path, delimiter=';')
    mapnames = df['MAPNAME'].tolist()
except FileNotFoundError:
    print(f"Soubor {input_csv_path} nebyl nalezen.")
    mapnames = []
except Exception as e:
    print(f"Chyba při načítání souboru: {e}")
    mapnames = []

# URL hlavního feedu
main_feed_url = "https://atom.cuzk.cz/DMR5G-SJTSK/DMR5G-SJTSK.xml"

# Stažení hlavního feedu
response = requests.get(main_feed_url)

if response.status_code == 200 and mapnames:
    root = ET.fromstring(response.content)
    namespace = {'atom': 'http://www.w3.org/2005/Atom'}

    # Iterace přes záznamy a filtrování podle názvu
    for entry in root.findall('atom:entry', namespace):
        title = entry.find('atom:title', namespace).text if entry.find('atom:title', namespace) is not None else ""
        feed_url = entry.find('atom:id', namespace).text if entry.find('atom:id', namespace) is not None else ""

        # Porovnání názvu se seznamem mapových listů
        if any(mapname in title for mapname in mapnames):
            print(f"Zpracovávám mapový list: {title}")
            print(f"URL feedu: {feed_url}\n")

            # Stažení jednotlivého feedu
            feed_response = requests.get(feed_url)
            if feed_response.status_code == 200:
                sub_root = ET.fromstring(feed_response.content)

                # Iterace přes záznamy feedu a hledání ZIP souboru
                for sub_entry in sub_root.findall('atom:entry', namespace):
                    zip_link = sub_entry.find('atom:link', namespace)
                    if zip_link is not None:
                        zip_url = zip_link.attrib.get('href')
                        if zip_url and zip_url.endswith('.zip'):
                            print(f"Stahuji ZIP: {zip_url}")
                            zip_response = requests.get(zip_url)

                            if zip_response.status_code == 200:
                                zip_filename = os.path.basename(zip_url)
                                output_path = os.path.join(output_folder, zip_filename)
                                with open(output_path, 'wb') as f:
                                    f.write(zip_response.content)
                                print(f"Stažen ZIP: {output_path}")
                            else:
                                print(f"Chyba při stahování ZIP: {zip_url}")
else:
    print(f"Chyba při stahování hlavního feedu nebo prázdný seznam mapových listů.")
