## Markdown popis stylu pop-up okna pro Map Viewer ArcGIS Online

Níže najdete **markdown dokumentaci** k popisu stylu a struktury pop-up okna v Map Vieweru ArcGIS Online, odpovídající vašemu kódu (Arcade expression s generováním HTML obsahu). Tento popis můžete použít jako dokumentaci pro tým, zadání pro další úpravy, nebo jako vysvětlení pro uživatele.

---

### Popis struktury pop-up okna

Pop-up okno je generováno pomocí Arcade výrazu, který sestavuje HTML obsah na základě atributů vybraného prvku. Výsledné okno je přehledně rozděleno do tematických bloků, které vizualizují technické informace, dopravní data, rozložení jízd, nehodovost a intenzitu dopravy.

#### **Hlavní části pop-upu:**

- **Technické informace**
  - Typ komunikace
  - Název úseku
  - Povrch a kvalita povrchu
  - Maximální rychlost (pokud je k dispozici)
  - OSM ID (pokud je k dispozici)

- **Doprava (Strava)**
  - ID Strava úseku
  - Jednosměrnost komunikace a pro kola (pokud je k dispozici)
  - Celkový počet cest za roky 2023 a 2024
  - Počet jízd vpřed a vzad (2024)
  - Průměrná rychlost (2024, pokud je k dispozici)

- **Vizualizace jízd vpřed a vzad (2024)**
  - Dva horizontální sloupce vedle sebe, délka odpovídá podílu jízd vpřed/vzad vůči maximu

- **Podíl pracovních a volnočasových cest (2024)**
  - Dva horizontální sloupce vedle sebe, délka odpovídá procentuálnímu podílu

- **Srovnání jízd (Strava) 2023 vs. 2024**
  - Dva horizontální sloupce vedle sebe, délka odpovídá relativnímu počtu jízd v daném roce

- **Denní rozložení jízd**
  - Pro každý den v týdnu: název dne, procento a barevný sloupec (pondělí–pátek modrá, víkend zelená)

- **Rozložení podle denní doby**
  - Ráno, poledne, podvečer: počet jízd a barevný sloupec (každá část dne jinou barvou)

- **Nehody a přestupky**
  - Počet nehod, nejčastější příčina, nejčastější kategorie přestupků, počet přestupků

- **Intenzita dopravy BKOM**
  - Intenzita cyklistů (2022) a automobilů (2023) za 24h

---

### **Použité vizuální prvky a styly**

- **Bloky jsou odděleny tagem ``** a zvýrazněny tučným nadpisem (``).
- **Horizontální sloupce** (bar charts) jsou tvořeny `` s nastavenou šířkou v procentech, barvou pozadí, zaoblenými rohy a bílým textem.
- **Barvy sloupců**:
  - Modrá (`#007bff`): pracovní/pro běžné dny
  - Zelená (`#28a745`): volnočasové/víkendové dny
  - Další barvy pro denní doby: zelená, žlutá, fialová

- **Podmíněné zobrazování**: Pokud některý údaj chybí (je `null`), není zobrazen nebo je nahrazen výchozí hodnotou ("Neznámá", `0` apod.).

---

### **Ukázka výsledného HTML (zkrácená):**

```html

    Technické informace:
    - Typ komunikace: ...
    - Název úseku: ...
    ...


    Doprava Strava:
    - ID Strava úseku: ...
    ...


    Podíl jízd vpřed a vzad (2024):
    
        60 (Vpřed)
        40 (Vzad)
    


```

---

### **Doporučení pro úpravy a rozšíření**

- **Přidání ikon**: Lze doplnit ikony pomocí `` nebo Unicode symbolů pro ještě lepší vizualizaci.
- **Responsivita**: Pro zajištění správného zobrazení na mobilních zařízeních doporučujeme používat procentuální šířky a jednoduché styly.
- **Barvy a stylování** lze dále upravit podle grafického manuálu nebo potřeb projektu.

---

### **Implementace v Map Vieweru**

- Arcade výraz vkládáte do nastavení pop-upu vrstvy jako vlastní výraz (expression) a výsledek použijete v sekci „Vlastní atributové zobrazení“ (`Custom Attribute Display`) nebo přímo v HTML šabloně pop-upu
- Výsledkem je pop-up, který je vizuálně přehledný, informativní a snadno rozšiřitelný.

---

