# 🛠 Nástroj: Přiřazení linie auta + cyklo

Tento nástroj slouží k prostorovému párování tras jízdních dat (cyklo/auto) s daty z OpenStreetMap. Výsledkem je datová sada obohacená o informace o infrastruktuře, směrových charakteristikách a vhodnosti trasy. Skript umožňuje pracovat jak s cyklistickými trasami, tak s automobilovými.

---

## 📂 Vstupní data

Veškeré vstupní vrstvy jsou dostupné v rámci geodatabáze:

```
komplexni_datova_sada.gdb
```

Tato geodatabáze obsahuje všechny potřebné vrstvy pro běh nástroje, včetně linií, bodů i rastrových podkladů.

---


## 📂 skript na pozadí

Toolbox má již v sobě integrovaný python kód, pro případ vytváření nového nástoroje na zákaldě tohoto skirptu je nutné použít:

```
prirazeni_obou_linii.py
```


---

## 🧾 Parametry nástroje
### V případě ručního nastavení parametrů toolboxů je nutné použít tyto parametry

### V případě ručního nastavení parametrů toolboxu je nutné použít tyto parametry a konkrétní vrstvy z geodatabáze `komplexni_datova_sada.gdb` ve složce toolboxu.
| Label                                          | Name                                      | Data Type       | Type     | Direction | Doporučená vrstva z GDB                  |
|-----------------------------------------------|-------------------------------------------|------------------|----------|-----------|------------------------------------------|
| Vstupní OSM vrstva                             | Vstupní_OSM_vrstva                         | Feature Layer     | Required | Input     | `strava_base_osm`                         |
| Výstupní body OSM                              | Výstupní_body_OSM                          | Feature Class     | Required | Output    | -                                         |
| Interval rozdělení OSM [m]                     | Interval_rozdělení_OSM                     | Double            | Required | Input     | -                                         |
| Výstupní rozdělené linie OSM                   | Výstupní_rozdělené_linie_OSM               | Feature Class     | Required | Output    | -                                         |
| Vstupní pentlogramová vrstva cyklo            | Vstupní_pentlogramová_vrstva               | Feature Layer     | Required | Input     | `intenzita_cyklodopravy_pentlogramy`     |
| Výstupní body pentlogramu cyklo                | Výstupní_body_pentlogramu                  | Feature Class     | Required | Output    | -                                         |
| Interval rozdělení pentlogramu [m] cyklo       | Interval_rozdělení_pentlogramu             | Double            | Required | Input     | -                                         |
| Výstupní rozdělené linie pentlogramu cyklo     | Výstupní_rozdělené_linie_pentlogramu       | Feature Class     | Required | Output    | -                                         |
| Vzdálenost pro vyhledání úseku [m] cyklo       | Vzdálenost_pro_vyhledání_úseku             | Double            | Required | Input     | -                                         |
| Vstupní pentlogramová vrstva auta             | Vstupní_pentlogramová_vrstva_auta          | Feature Class     | Required | Input     | `intenzita_cars_pentlogramy`             |
| Výstupní body pentlogramu auta                 | Výstupní_body_pentlogramu_auta             | Feature Class     | Required | Output    | -                                         |
| Interval rozdělení pentlogramu [m] auta        | Interval_rozdělení_pentlogramu_[m]_auta    | Double            | Required | Input     | -                                         |
| Výstupní rozdělené linie pentlogramu auta      | Výstupní_rozdělené_linie_pentlogramu_auta  | Feature Class     | Required | Output    | -                                         |
| Vzdálenost pro vyhledání úseku [m] auta        | Vzdálenost_pro_vyhledání_úseku_auta        | Double            | Required | Input     | -                                         |
| Vstupní raster                                 | Vstupní_raster                              | Raster Layer      | Required | Input     | `raster`                                 |
---

## 🧮 Funkcionalita nástroje

- Segmentace liniových tras (cyklo i auto) podle zadaného intervalu
- Výpočet základních geometrických atributů: délka, azimut, směr
- Generování bodových reprezentací segmentů
- Vyhledání nejbližších úseků v OSM vrstvě dle vzdálenosti a směrové podobnosti
- Výstupní vrstvy připravené pro další analýzu: heatmapy, směrové vizualizace, střední azimuty atd.

---

## 📤 Výstupy

Nástroj generuje následující výstupy:

- **Výstupní_body_OSM** – rozdělené body na OSM linii
- **Výstupní_rozdělené_linie_OSM** – segmentovaná OSM linie- Hlavní výstup skriptu
- **Výstupní_body_pentlogramu** – segmentované cyklo trasy
- **Výstupní_rozdělené_linie_pentlogramu** – rozdělené úseky cyklo tras
- **Výstupní_body_pentlogramu_auta** – segmentované auto trasy
- **Výstupní_rozdělené_linie_pentlogramu_auta** – rozdělené úseky auto tras

---

## 📌 Doporučené hodnoty parametrů

| Parametr                                 | Doporučená hodnota     |
|------------------------------------------|--------------------------|
| Interval_rozdělení_OSM                   | 100 m              |
| Interval_rozdělení_pentlogramu           | 100 m             |
| Vzdálenost_pro_vyhledání_úseku           | 17 m                     |
| Vzdálenost_pro_vyhledání_úseku_auta      | 17 m                     |

---



## ✏️ Autor / poznámky

Tento nástroj vznikl pro potřeby analýzy dat z bikesharingu a dopravy ve městě Brně. Lze jej adaptovat i pro jiná města či jiné formy prostorových dat.
